==> openGion6.9.5.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE38S.sql <==
/****************************************************************************/
/* GE38 ( ﾌｧｲﾙ種別ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/03/29 14:26:15                                            */
/****************************************************************************/

CREATE TABLE GE38 (
   SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR  (  100 )                   NOT NULL            /*  20 ﾌｧｲﾙ種別     */
 , SYNAME       VARCHAR  (  200 )                                       /*  30 種別名称     */
 , DESCRIPTION  VARCHAR  ( 4000 )                                       /*  40 概要説明     */
 , HINAGATA     VARCHAR  (  300 )                                       /*  50 雛形ﾌｧｲﾙ     */
 , SAVE_FOLDER  VARCHAR  (  300 )                                       /*  60 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR  (  300 )                                       /*  70 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR  (  300 )                                       /*  80 ｱｲｺﾝURL      */
 , ROLES        VARCHAR  (  500 )                                       /*  90 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 100 閲覧制限数   */
 , DY_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 110 閲覧期日     */
 , SIZE_LMT     INTEGER                 DEFAULT 0   NOT NULL            /* 120 ｻｲｽﾞ制限     */
 , SUFFIX_LMT   VARCHAR  (  200 )                                       /* 130 拡張子制限   */
 , FGANGO       VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者       */
);

==> openGion7.2.2.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE38S.sql <==
/****************************************************************************/
/* GE38 ( ﾌｧｲﾙ種別ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GE38 (
   SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR  (  100 )                   NOT NULL            /*  20 ﾌｧｲﾙ種別     */
 , SYNAME       VARCHAR  (  200 )                                       /*  30 種別名称     */
 , DESCRIPTION  VARCHAR  ( 4000 )                                       /*  40 概要説明     */
 , HINAGATA     VARCHAR  (  300 )                                       /*  50 雛形ﾌｧｲﾙ     */
 , SAVE_FOLDER  VARCHAR  (  300 )                                       /*  60 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR  (  300 )                                       /*  70 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR  (  300 )                                       /*  80 ｱｲｺﾝURL      */
 , ROLES        VARCHAR  ( 2000 )                                       /*  90 ﾛｰﾙｽﾞ        */
 , SU_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 100 閲覧制限数   */
 , DY_LMT       INTEGER                 DEFAULT 0   NOT NULL            /* 110 閲覧期日     */
 , SIZE_LMT     INTEGER                 DEFAULT 0   NOT NULL            /* 120 ｻｲｽﾞ制限     */
 , SUFFIX_LMT   VARCHAR  (  200 )                                       /* 130 拡張子制限   */
 , FGANGO       VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者       */
);
